==> tlotd-0.3.8%20-%201.20.1-sources.jar: net/tlotd/item/custom/AbyssFlaskItem.java <==
package net.tlotd.item.custom;

import net.minecraft.class_124;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_174;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_1838;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_2680;
import net.minecraft.class_2960;
import net.minecraft.class_3222;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3468;
import net.minecraft.class_437;
import net.tlotd.block.ModBlocks;
import net.tlotd.item.ModItems;
import org.jetbrains.annotations.Nullable;

import java.util.List;

import static net.tlotd.block.custom.WitchingTableBlock.*;
import static net.tlotd.block.custom.WitchingTableBlock.CURSED_SOUL_CHARGES;

public class AbyssFlaskItem extends class_1792 {
    public AbyssFlaskItem(class_1793 settings) { super(settings); }

    @Override
    public class_1269 method_7884(class_1838 context) {
        if(!context.method_8045().method_8608()) {
            class_1799 item = context.method_8036().method_5998(context.method_20287());
            class_2338 positionClicked = context.method_8037();
            class_1657 player = context.method_8036();
            class_2680 block = context.method_8045().method_8320(positionClicked);
            if (block.method_27852(ModBlocks.WITCHING_TABLE) && (block.method_11654(SOUL_CHARGES)+block.method_11654(CURSED_SOUL_CHARGES)+block.method_11654(ABYSSAL_SOUL_CHARGES))<3) {
                int charges = block.method_11654(ABYSSAL_SOUL_CHARGES);
                context.method_8045().method_8652(positionClicked, block.method_11657(ABYSSAL_SOUL_CHARGES, charges+1), 2);
                context.method_8045().method_8396(null, positionClicked, class_3417.field_23116, class_3419.field_15245, 1.0f, 1.0f);
                if (player instanceof class_3222 serverPlayerEntity) {
                    class_174.field_1198.method_8821(serverPlayerEntity, context.method_8041());
                    serverPlayerEntity.method_7259(class_3468.field_15372.method_14956(this));
                }
                item.method_7934(1);
                context.method_8036().method_7270(ModItems.TINTED_GLASS_FLASK.method_7854());
                return class_1269.field_5812;
            }
        }
        return class_1269.field_5814;
    }

    public static final class_2960 DEFAULT_FONT_ID = new class_2960("minecraft", "default");
    public static final class_2960 ILLAGER_FONT_ID = new class_2960("minecraft", "illageralt");

    @Override
    public boolean method_7886(class_1799 stack) {
        return true;
    }

    @Override
    public void method_7851(class_1799 stack, @Nullable class_1937 world, List<class_2561> tooltip, class_1836 context) {
        if (class_437.method_25442()) {
            tooltip.add(class_2561.method_43471("item.tlotd.soul_flask_of_the_abyss.tooltip").method_27692(class_124.field_1080));
            tooltip.add(class_2561.method_43471("item.tlotd.soul_flask_of_the_abyss.tooltip_2").method_27692(class_124.field_1080));
            tooltip.add(class_2561.method_43471("item.tlotd.soul_flask_of_the_abyss.tooltip_3").method_27692(class_124.field_1080));
            tooltip.add(class_2561.method_43471("item.tlotd.soul_flask_of_the_abyss.tooltip_4").method_27692(class_124.field_1080));
        } else {
            class_2583 style = method_7848().method_10866();
            tooltip.add(class_2561.method_43470("Und wenn du lange in").method_10862(style.method_27704(ILLAGER_FONT_ID)).method_27692(class_124.field_1080));
            tooltip.add(class_2561.method_43470("einen Abgrund blickst").method_10862(style.method_27704(ILLAGER_FONT_ID)).method_27692(class_124.field_1080).method_10852(class_2561.method_43470(",").method_10862(style.method_27704(DEFAULT_FONT_ID)).method_27692(class_124.field_1080)));
            tooltip.add(class_2561.method_43470("blickt der Abgrund").method_10862(style.method_27704(ILLAGER_FONT_ID)).method_27692(class_124.field_1080));
            tooltip.add(class_2561.method_43470("auch in dich hinein").method_10862(style.method_27704(ILLAGER_FONT_ID)).method_27692(class_124.field_1080).method_10852(class_2561.method_43470(",").method_10862(style.method_27704(DEFAULT_FONT_ID)).method_27692(class_124.field_1080)));
        }
        super.method_7851(stack, world, tooltip, context);
    }
}

==> tlotd-0.3.9%20-%201.20.1-sources.jar: net/tlotd/item/custom/AbyssFlaskItem.java <==
package net.tlotd.item.custom;

import net.minecraft.class_124;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_174;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_1838;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_2680;
import net.minecraft.class_2960;
import net.minecraft.class_3222;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3468;
import net.minecraft.class_437;
import net.tlotd.block.ModBlocks;
import net.tlotd.item.ModItems;
import org.jetbrains.annotations.Nullable;

import java.util.List;

import static net.tlotd.block.custom.WitchingTableBlock.*;
import static net.tlotd.block.custom.WitchingTableBlock.CURSED_SOUL_CHARGES;

public class AbyssFlaskItem extends class_1792 {
    public AbyssFlaskItem(class_1793 settings) { super(settings); }

    @Override
    public class_1269 method_7884(class_1838 context) {
        if(!context.method_8045().method_8608()) {
            class_1799 item = context.method_8036().method_5998(context.method_20287());
            class_2338 positionClicked = context.method_8037();
            class_1657 player = context.method_8036();
            class_2680 block = context.method_8045().method_8320(positionClicked);
            if (block.method_27852(ModBlocks.WITCHING_TABLE) && (block.method_11654(SOUL_CHARGES)+block.method_11654(CURSED_SOUL_CHARGES)+block.method_11654(ABYSSAL_SOUL_CHARGES))<3) {
                int charges = block.method_11654(ABYSSAL_SOUL_CHARGES);
                context.method_8045().method_8652(positionClicked, block.method_11657(ABYSSAL_SOUL_CHARGES, charges+1), 2);
                context.method_8045().method_8396(null, positionClicked, class_3417.field_23116, class_3419.field_15245, 1.0f, 1.0f);
                if (player instanceof class_3222 serverPlayerEntity) {
                    class_174.field_1198.method_8821(serverPlayerEntity, context.method_8041());
                    serverPlayerEntity.method_7259(class_3468.field_15372.method_14956(this));
                }
                item.method_7934(1);
                context.method_8036().method_7270(ModItems.TINTED_GLASS_FLASK.method_7854());
                return class_1269.field_5812;
            }
        }
        return class_1269.field_5814;
    }

    public static final class_2960 DEFAULT_FONT_ID = new class_2960("minecraft", "default");
    public static final class_2960 ILLAGER_FONT_ID = new class_2960("minecraft", "illageralt");

    @Override
    public boolean method_7886(class_1799 stack) {
        return true;
    }

    @Override
    public class_2561 method_7864(class_1799 stack) {
        return class_2561.method_43471(this.method_7876()).method_27694(style -> style.method_36139(0x3C009C));
    }
    
    @Override
    public void method_7851(class_1799 stack, @Nullable class_1937 world, List<class_2561> tooltip, class_1836 context) {
        class_2583 style = method_7848().method_10866();
        if (class_437.method_25442()) {
            tooltip.add(class_2561.method_43471("item.tlotd.soul_flask_of_the_abyss.tooltip").method_27692(class_124.field_1080));
            tooltip.add(class_2561.method_43471("item.tlotd.soul_flask_of_the_abyss.tooltip_2").method_27692(class_124.field_1080));
            tooltip.add(class_2561.method_43471("item.tlotd.soul_flask_of_the_abyss.tooltip_3").method_27692(class_124.field_1080));
            tooltip.add(class_2561.method_43471("item.tlotd.soul_flask_of_the_abyss.tooltip_4").method_27692(class_124.field_1080));
        } else {
            tooltip.add(class_2561.method_43470("Und wenn du lange in").method_10862(style.method_27704(ILLAGER_FONT_ID)).method_27692(class_124.field_1080));
            tooltip.add(class_2561.method_43470("einen Abgrund blickst").method_10862(style.method_27704(ILLAGER_FONT_ID)).method_27692(class_124.field_1080).method_10852(class_2561.method_43470(",").method_10862(style.method_27704(DEFAULT_FONT_ID)).method_27692(class_124.field_1080)));
            tooltip.add(class_2561.method_43470("blickt der Abgrund").method_10862(style.method_27704(ILLAGER_FONT_ID)).method_27692(class_124.field_1080));
            tooltip.add(class_2561.method_43470("auch in dich hinein").method_10862(style.method_27704(ILLAGER_FONT_ID)).method_27692(class_124.field_1080).method_10852(class_2561.method_43470(",").method_10862(style.method_27704(DEFAULT_FONT_ID)).method_27692(class_124.field_1080)));
        }
        tooltip.add(class_2561.method_43471("item.tlotd.desc_eldritch").method_10862(style.method_36139(0x3C009C)));
        super.method_7851(stack, world, tooltip, context);
    }
}
